[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/flint-crew/flint/main.svg)](https://results.pre-commit.ci/latest/github/flint-crew/flint/main)
[![codecov](https://codecov.io/gh/flint-crew/flint/graph/badge.svg?token=7ZEKJ78TBZ)](https://codecov.io/gh/flint-crew/flint)

# flint

<!-- SPHINX-START -->

A pirate themed ASKAP pipeline.

Yarrrr-Harrrr fiddly-dee!

<img src="_static/logo.jpeg" alt="Capn' Flint - Credit: DALLE 3" style="width:400px;"/>

## Documentation

Full documentation is provided on
[ReadtheDocs](https://askap-flint.readthedocs.io/).

## Contributions

Contributions are welcome! Please do submit a pull-request or issue if you spot
something you would like to address.

The pre-packed module may be installed from PyPi:

```bash
pip install askap-flint
```
The full set of dev tooling can be installed via:

```bash
git clone https://github.com/flint-crew/flint.git
cd flint
pip install '.[dev]'
```
